@@ -1,12 +1,14 @@
-# $Id: /local/Mango/trunk/lib/Mango/Cart.pm 155 2007-04-16T02:58:37.637652Z claco  $
+# $Id: /local/Mango/trunk/lib/Mango/Cart.pm 169 2007-04-22T00:02:47.419841Z claco  $
 package Mango::Cart;
 use strict;
 use warnings;
 
 BEGIN {
     use base qw/Handel::Cart/;
+    use Mango::User ();
     use Mango::Exception ();
     use DateTime ();
+    use Scalar::Util ();
 };
 
 ## Yes, this isn't the preferred way. Sue me. I don't want the storage classes
@@ -29,11 +31,29 @@ __PACKAGE__->result_iterator_class('Mango::Iterator');
 __PACKAGE__->create_accessors;
 
 sub type {
-    throw Mango::Exception('METHOD_NOT_IMPLEMENTED');
+    Mango::Exception->throw('METHOD_NOT_IMPLEMENTED');
 };
 
 sub save {
-    throw Mango::Exception('METHOD_NOT_IMPLEMENTED');
+    Mango::Exception->throw('METHOD_NOT_IMPLEMENTED');
+};
+
+sub user {
+    my ($self, $user) = @_;
+
+    if (defined $user) {
+        if (Scalar::Util::blessed $user) {
+            if ($user->isa('Mango::User')) {
+                $user = $user->id;
+            } else {
+                Mango::Exception->throw('NOT_A_USER');
+            };
+        };
+
+        $self->user_id($user);
+    } else {
+        Mango::Exception->throw('NO_USER_SPECIFIED');
+    };
 };
 
 sub update {
@@ -49,7 +69,7 @@ __END__
 
 =head1 NAME
 
-Mango::Cart - Module for maintaining shopping cart contents
+Mango::Cart - Module representing a shopping cart
 
 =head1 SYNOPSIS
 
@@ -63,17 +83,17 @@ Mango::Cart - Module for maintaining shopping cart contents
         price    => 1.25
     });
     
-    my $iterator = $cart->items;
-    while (my $item = $iterator->next) {
+    my $items = $cart->items;
+    while (my $item = $items->next) {
         print $item->sku;
         print $item->price;
         print $item->total;
     };
-    $item->subtotal;
+    print $cart->subtotal;
 
 =head1 DESCRIPTION
 
-Mango::Cart is component for maintaining simple shopping cart data.
+Mango::Cart represents a users shopping cart and cart contents.
 
 =head1 METHODS
 
@@ -85,9 +105,8 @@ Mango::Cart is component for maintaining simple shopping cart data.
 
 =back
 
-Adds a new item to the current shopping cart and returns an instance of the
-item class. You can either pass the item
-data as a hash reference:
+Adds a new item to the current shopping cart and returns the new item. You can
+pass in the item data as a hash reference:
 
     my $item = $cart->add({
         sku      => 'SKU1234',
@@ -102,9 +121,10 @@ or pass an existing cart item:
     );
 
 When passing an existing cart item to add, all columns in the source item will
-be copied into the destination item if the column exists in both the
-destination and source, and the column isn't the primary key or the foreign
-key of the item relationship.
+be copied into the destination item if the column exists in the destination and
+the column isn't the primary key or the foreign key of the item relationship.
+
+The item object passed to add must be an instance or subclass of Handel::Cart.
 
 =head2 clear
 
@@ -114,10 +134,16 @@ Deletes all items from the current cart.
 
 =head2 count
 
-Returns the number of items in the cart object.
+Returns the number of items in the cart.
 
     my $numitems = $cart->count;
 
+=head2 created
+
+Returns the date and time in UTC the cart was created as a DateTime object.
+
+    print $cart->created;
+
 =head2 delete
 
 =over
@@ -126,7 +152,7 @@ Returns the number of items in the cart object.
 
 =back
 
-Deletes the item matching the supplied filter from the current cart.
+Deletes the item(s) matching the supplied filter from the current cart.
 
     $cart->delete({
         sku => 'ABC-123'
@@ -134,7 +160,13 @@ Deletes the item matching the supplied filter from the current cart.
 
 =head2 destroy
 
-Deletes the current item from the provider.
+Deletes the current cart and all of its items.
+
+=head2 id
+
+Returns the id of the current cart.
+
+    print $cart->id;
 
 =head2 items
 
@@ -149,6 +181,7 @@ L<Mango::Iterator|Mango::Iterator> in scalar context, or a list of items in
 list context.
 
     my $iterator = $cart->items;
+    
     while (my $item = $iterator->next) {
         print $item->sku;
     };
@@ -178,20 +211,19 @@ style syntax:
 
 =back
 
-Copies (restores) items from a cart, or a set of carts back into the current
-shopping cart. You may either pass in a hash reference containing the search
-criteria of the shopping cart(s) to restore:
+Copies (restores) items from a cart/wishlist, or a set of carts/wishlist back
+into the current cart. You may either pass in a hash reference containing the
+search criteria of the cart(s) to restore:
 
     $cart->restore({
-        shopper => 'D597DEED-5B9F-11D1-8DD2-00AA004ABD5E',
-        type    => CART_TYPE_SAVED
+        id => 23
     });
 
-or you can pass in an existing C<Mango::Cart> object or subclass.
+or you can pass in an existing C<Mango::Cart> or C<Mango::Wishlist> object
+or subclass.
 
-    my $wishlist = Mango::Cart->search({
-        id   => 23,
-        type => CART_TYPE_SAVED
+    my $wishlist = Mango::Wishlist->search({
+        id   => 23
     })->first;
     
     $cart->restore($wishlist);
@@ -208,51 +240,58 @@ into it. This is the default if no mode is specified.
 
 =item C<CART_MODE_MERGE>
 
-If an item with the same SKU exists in both the current cart and the saved cart,
-the quantity of each will be added together and applied to the same sku in the
-current cart. Any price differences are ignored and we assume that the price in
-the current cart has the more up to date price.
+If an item with the same SKU exists in both the current cart and the saved
+cart/wishlist, the quantity of each will be added together and applied to
+the same sku in the current cart. Any price differences are ignored and we
+assume that the price in the current cart has the more up to date price.
 
 =item C<CART_MODE_APPEND>
 
 All items in the saved cart will be appended to the list of items in the current
 cart. No effort will be made to merge items with the same SKU and duplicates
-will be ignored.
+will be allowed.
 
 =back
 
-=head2 id
-
-Returns the id of the current cart.
-
-    print $cart->id;
-
 =head2 subtotal
 
-Returns the current total price of all the items in the cart object as a
-stringified L<Mango::Currency|Mango::Currency> object. This is equivalent to:
+Returns the current total price of all the items in the cart as a
+L<Mango::Currency|Mango::Currency> object. This is equivalent to:
 
-    my $iterator = $cart->items;
+    my $items = $cart->items;
     my $subtotal = 0;
-    while (my $item = $iterator->next) {
+    
+    while (my $item = $items->next) {
         $subtotal += $item->quantity*$item->price;
     };
 
-=head2 created
+=head2 update
 
-Returns the date the cart was created as a DateTime object.
+Saves any changes made to the cart back to the provider.
 
-    print $cart->created;
+    $cart->user(23);
+    $cart->update;
+
+Whenever L</update> is called, L</updated> is automatically set to the
+current time in UTC.
 
 =head2 updated
 
-Returns the date the cart was last updated as a DateTime object.
+Returns the date and time in UTC the cart was last updated as a DateTime
+object.
 
     print $cart->updated;
 
-=head2 update
+=head2 user
 
-Saves any changes to the cart back to the provider.
+=over
+
+=item Arguments: $user
+
+=back
+
+Assigns the current cart to the specified user. This can be a Mango::User
+object or the user id.
 
 =head1 SEE ALSO
 
