@@ -1,4 +1,4 @@
-# $Id: /local/Mango/trunk/lib/Mango/Wishlist/Item.pm 150 2007-04-14T02:57:04.324056Z claco  $
+# $Id: /local/Mango/trunk/lib/Mango/Wishlist/Item.pm 167 2007-04-21T03:53:20.211692Z claco  $
 package Mango::Wishlist::Item;
 use strict;
 use warnings;
@@ -42,19 +42,38 @@ Mango::Wishlist::Item - Module representing an individual wishlist item
 
 =head1 SYNOPSIS
 
-    use Mango::Wishlist::Item;
+    my $items = $wishlist->items;
     
-    my $items = $cart->items;
     while (my $item = $items->next) {
         print $item->sku;
     };
 
 =head1 DESCRIPTION
 
-Mango::Wishlist::Item represent a part in the wishlist to be ordered.
+Mango::Wishlist::Item represents an individual wishlist item.
 
 =head1 METHODS
 
+=head2 created
+
+Returns the date and time in UTC the wishlist item was created as a DateTime
+object.
+
+    print $item->created;
+
+=head2 description
+
+=over
+
+=item Arguments: $description
+
+=back
+
+Gets/sets the description for the current wishlist item.
+
+    $item->description('Best Item Ever');
+    print $item->description;
+
 =head2 id
 
 Returns the id of the current wishlist item.
@@ -74,6 +93,21 @@ Gets/sets the sku (stock keeping unit/part number) for the wishlist item.
     $item->sku('ABC123');
     print $item->sku;
 
+=head2 price
+
+=over
+
+=item Arguments: $price
+
+=back
+
+Gets/sets the price for the current wishlist item. The price is returned as a
+L<Mango::Currency|Mango::Currency> object.
+
+    $item->price(12.95);
+    print $item->price;
+    print $item->price->format;
+
 =head2 quantity
 
 =over
@@ -87,46 +121,31 @@ Gets/sets the quantity, or the number of this item being purchased.
     $item->quantity(3);
     print $item->quantity;
 
-=head2 price
-
-=over
-
-=item Arguments: $price
-
-=back
-
-Gets/sets the price for the wishlist item. The price is returned as a stringified
-L<Mango::Currency|Mango::Currency> object.
-
-    $item->price(12.95);
-    print $item->price;
-    print $item->price->format;
-
 =head2 total
 
-Returns the total price for the wishlist item as a stringified
-L<Mango::Currency|Mango::Currency> object. This is really just
-quantity*total and is provided for convenience.
+Returns the total price for the wishlist item as a
+L<Mango::Currency|Mango::Currency> object. This is really just quantity*total
+and is provided for convenience.
 
     print $item->total;
     print $item->total->format;
 
-=head2 description
-
-=over
-
-=item Arguments: $description
-
-=back
-
-Gets/sets the description for the current wishlist item.
-
-    $item->description('Best Item Ever');
-    print $item->description;
-
 =head2 update
 
-Saves any changes made to the current item.
+Saves any changes made to the wishlist item back to the provider.
+
+    $item->quantity(2);
+    $item->update;
+
+Whenever L</update> is called, L</updated> is automatically set to the
+current time in UTC.
+
+=head2 updated
+
+Returns the date and time in UTC the wishlist item was last updated as a
+DateTime object.
+
+    print $item->updated;
 
 =head1 SEE ALSO
 
